Function set_threads

pub fn set_threads(t: usize) -> Option<()>
This function will set the max number of threads allowed to use.

Use it carefully, a big number of threads may decrease the performance. The default number of threads is 32.

In case the number of threads can’t be updated this function will return None, in case of success Some(()) is returned.