Struct ModpackMaker

pub struct ModpackMaker { /* private fields */ }
This struct is responsible for the creation of the modpacks given a minecraft path.

Implementations

Source

impl ModpackMaker

pub fn new<I: AsRef<Path>, J: AsRef<Path>>( path: I, modpack_name: J, ) -> ModpackMaker

pub fn start(&mut self) -> Result<()>

Starts the mod maker process.

This method initializes the mod maker, reads the mods, and prepares internal data structures for processing.

Errors

This method can return an error of type UraniumError in the following cases:

  • If there is an error while reading the mods.
Returns

This method returns Ok(()) if the mod maker was successfully started and prepared for processing.

Example
use uranium_rs::modpack_maker::ModpackMaker;
use uranium_rs::error::UraniumError;

let mut mod_maker = ModpackMaker::new("path/to/your/modpack", "my_modpack");

match mod_maker.start() {
    Ok(()) => println!("Mod maker started successfully!"),
    Err(err) => eprintln!("Error starting mod maker: {:?}", err),
}
pub async fn finish(&mut self) -> Result<()>

Finishes the mod maker process.

This asynchronous method continues processing chunks until the mod maker has completed its work.

Errors

This method can return an error of type UraniumError if any error occurs during the mod making process.

Returns

This method returns Ok(()) if the mod maker has successfully completed its work.

Example
    use uranium_rs::modpack_maker::ModpackMaker;
    use uranium_rs::error::UraniumError;

    let mut mod_maker = ModpackMaker::new("your/modpack/path", "my_modpack");

    match mod_maker.finish().await {
        Ok(()) => println!("Mod maker finished successfully!"),
        Err(err) => eprintln!("Error finishing mod maker: {:?}", err),
    }
pub fn len(&self) -> usize

Returns how many mods are in the minecraft directory

pub fn is_empty(&self) -> bool

Returns true if there are no mods in the minecraft directory

pub fn chunks(&self) -> usize

Returns how many chunks the struct will download

The formula is: self.len() / self.threads

pub async fn chunk(&mut self) -> Result<State>

This method will make progress until Ok(State::Finish) is returned or throw an Err.

It will return the current State of the process.

Errors

In case any of the steps fails this method will return Err(UraniumError) with the cause.

Can return any of the following variants:

  • UraniumError::CantReadModsDir
  • UraniumError::CantCompress
  • UraniumError::CantRemoveJSON